#include <Arduino.h>

#define CALIBRATION_DURATION 30 //seconds

class PIR{
	unsigned int _pin;
	unsigned long _triggerDuration, _motionDetectedTime;
	bool _currentMotionState;
	void (*_startCallback)(void);
	void (*_stopCallback)(void);

public:
	PIR(unsigned int pin, unsigned long triggerDuration,  void (*startCallback)(void), void (*stopCallback)(void)){
		_pin = pin;
		_triggerDuration = triggerDuration;
		_startCallback = startCallback;
		_stopCallback = stopCallback;
	}

	void setup() {
		Serial.print("Starting PIR sensor");
		pinMode(_pin, INPUT);
		digitalWrite(_pin, LOW);
		for (int i=0; i<CALIBRATION_DURATION; i++){
			Serial.print(".");
			delay(1000); // 30 second "calibration" time
		}
		Serial.println("done");
	}

	void loop(){
		bool motionDetected = digitalRead(_pin) == HIGH;

		if (motionDetected) {
			_motionDetectedTime = millis();
			if (!_currentMotionState)
				_startCallback();
			_currentMotionState = motionDetected;
		}

		if (_currentMotionState && millis() >= _motionDetectedTime + _triggerDuration){
			_stopCallback();
			_currentMotionState = false;
		}
	}
};